Carousel class

Inheritance

Constructors

Carousel({required List<Widget> items, Color activateIndicatorColor = Colors.black, Curve animationPageCurve = Curves.easeIn, Duration animationPageDuration = Duration.zero, bool autoScroll = false, Duration autoScrollDuration = Duration.zero, double height = 0.0, double indicatorBarHeight = 0.0, double indicatorBarWidth = 0.0, double indicatorHeight = 10, double indicatorWidth = 10, int initialPage = 0, bool isCircle = true, Axis scrollAxis = Axis.horizontal, bool stopAtEnd = false, Color unActivatedIndicatorColor = Colors.grey, Color indicatorBarColor = Colors.black, double width = 0.0})

Properties

activateIndicatorColor Color
getter/setter pair
animationPageCurve Curve
getter/setter pair
animationPageDuration Duration
getter/setter pair
autoScroll bool
getter/setter pair
autoScrollDuration Duration
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height double
getter/setter pair
indicatorBarColor Color
getter/setter pair
indicatorBarColorOpacity double?
getter/setter pair
indicatorBarHeight double
getter/setter pair
indicatorBarWidth double
getter/setter pair
indicatorHeight double
getter/setter pair
indicatorWidth double
getter/setter pair
initialPage int
getter/setter pair
isCircle bool
getter/setter pair
items List<Widget>
getter/setter pair
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollAxis Axis
getter/setter pair
stopAtEnd bool
getter/setter pair
unActivatedIndicatorColor Color
getter/setter pair
width double
getter/setter pair

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CarouselState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited